@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.6.9"
+    version = "1.7.0"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -124,7 +124,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
         payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
-        payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__['fields_cache'].__dict__} \n\n"
+        payload = f"{payload} > _state: {json.loads(str(group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__['fields_cache']['organization'], encoding='utf-8'))} \n\n"
         # payload = f"{payload} > flags: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['flags'].__dict__} \n\n"
 
         headers = {
